pub struct Endpoint {
pub address: Option<String>,
pub annotations: Option<HashMap<String, String>>,
pub name: Option<String>,
pub network: Option<String>,
pub port: Option<i32>,
pub uid: Option<String>,
}Expand description
An individual endpoint that provides a service. The service must already exist to create an endpoint.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations namespaces services endpoints create projects (request|response)
- locations namespaces services endpoints get projects (response)
- locations namespaces services endpoints patch projects (request|response)
Fields
address: Option<String>Optional. An IPv4 or IPv6 address. Service Directory rejects bad addresses like: * 8.8.8 * 8.8.8.8:53 * test:bad:address * [::1] * [::1]:8080 Limited to 45 characters.
annotations: Option<HashMap<String, String>>Optional. Annotations for the endpoint. This data can be consumed by service clients. Restrictions: * The entire annotations dictionary may contain up to 512 characters, spread accoss all key-value pairs. Annotations that go beyond this limit are rejected * Valid annotation keys have two segments: an optional prefix and name, separated by a slash (/). The name segment is required and must be 63 characters or less, beginning and ending with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.), and alphanumerics between. The prefix is optional. If specified, the prefix must be a DNS subdomain: a series of DNS labels separated by dots (.), not longer than 253 characters in total, followed by a slash (/) Annotations that fails to meet these requirements are rejected. Note: This field is equivalent to the metadata field in the v1beta1 API. They have the same syntax and read/write to the same location in Service Directory.
name: Option<String>Immutable. The resource name for the endpoint in the format projects/*/locations/*/namespaces/*/services/*/endpoints/*.
network: Option<String>Immutable. The Google Compute Engine network (VPC) of the endpoint in the format projects//locations/global/networks/*. The project must be specified by project number (project id is rejected). Incorrectly formatted networks are rejected, we also check to make sure that you have the servicedirectory.networks.attach permission on the project specified.
port: Option<i32>Optional. Service Directory rejects values outside of [0, 65535].
uid: Option<String>Output only. The globally unique identifier of the endpoint in the UUID4 format.